#
# spec file for package deltarpm
#
# Copyright (c) 2012 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

# we don't want to provide private python extension libs
%define _exclude_files_from_autoprov %{python_sitearch}/.*\\.so\\|%{python3_sitearch}/.*\\.so
%define snap %nil

Name:           deltarpm
Version:        3.6
Release:        %mkrel 10
Summary:        Tools to Create and Apply deltarpms
License:        BSD-3-Clause
Group:          System/Packaging
Url:            ftp://ftp.suse.com/pub/projects/deltarpm
%if 0%{?snap}
# Generate source by doing:
# git clone git://gitorious.org/deltarpm/deltarpm
# cd deltarpm
# git archive --format=tar --prefix="deltarpm-git-20120324/" 7ed5208 | \
# bzip2 > deltarpm-git-20120324.tar.bz2
Source:			%{name}-%{version}-20120324.tar.bz2
%else
Source: ftp://ftp.suse.com/pub/projects/deltarpm/%{name}-%{version}.tar.bz2
%endif
Patch1:			0003-initial-perl-binding.patch
BuildRequires:  libbzip2-devel
BuildRequires:  python-devel
BuildRequires:  python3-devel
BuildRequires:  rpm-devel
BuildRequires:  liblzma-devel
BuildRequires:  perl-devel
# we need to build against recent rpm, so avoid the new payload
%define _binary_payload w9.bzdio

%description
This package contains tools to create and apply deltarpms. A deltarpm
contains the difference between an old and a new version of an RPM,
which makes it possible to recreate the new RPM from the deltarpm and
the old one. You do not need to have a copy of the old RPM, because
deltarpms can also work with installed RPMs.

%package -n python-deltarpm
Summary:        Tools to Create and Apply deltarpms
Group:          Development/Python
Requires:       %{name} = %{version}

%description -n python-deltarpm
Python bindings for deltarpm

%package -n python3-deltarpm
Summary:        Tools to Create and Apply deltarpms
Group:          Development/Python
Requires:       %{name} = %{version}

%description -n python3-deltarpm
Python bindings for deltarpm

%package -n perl-deltarpm
Summary:        Tools to Create and Apply deltarpms
Group:          Development/Perl
Requires:       %{name} = %{version}

%description -n perl-deltarpm
Perl bindings for deltarpm

%prep
%if 0%{?snap}
%setup -q -n %{name}-git-20120324
%else
%setup -q
%endif
%apply_patches

%build
make rpmdumpheader="%{_libdir}/rpm/rpmdumpheader" %{?_smp_mflags} prefix=%{_prefix} mandir=%{_mandir} bindir=%{_bindir}
make rpmdumpheader="%{_libdir}/rpm/rpmdumpheader" %{?_smp_mflags} prefix=%{_prefix} mandir=%{_mandir} bindir=%{_bindir} python
pushd perl
perl Makefile.PL INSTALLDIRS=vendor
make
popd

%install
mkdir -p %{buildroot}%{_libdir}/rpm
make rpmdumpheader="%{_libdir}/rpm/rpmdumpheader" DESTDIR=%{buildroot} prefix=%{_prefix} mandir=%{_mandir} bindir=%{_bindir} install
# Remove wrongly installed Python module
rm -rf %{buildroot}%{_libdir}/python/site-packages/{_deltarpmmodule.so,deltarpm.py}
# Fix binary Python module name
mv %{buildroot}%{python_sitearch}/_deltarpm{module,}.so
rm -rf %{buildroot}/usr/local
%{makeinstall_std} -C perl

%files
%doc README LICENSE.BSD
%{_bindir}/*
%{_mandir}/man8/*
%{_libdir}/rpm/rpmdumpheader

%files -n python-deltarpm
%{python_sitearch}/deltarpm.py*
%{python_sitearch}/_deltarpm.so

%files -n python3-deltarpm
%{python3_sitearch}/deltarpm.py
%{python3_sitearch}/_deltarpmmodule.so
%{python3_sitearch}/__pycache__/deltarpm*

%files -n perl-deltarpm
%{perl_vendorarch}/auto/deltarpm/deltarpm.so
%{perl_vendorarch}/deltarpm.pm
%{_mandir}/man3/deltarpm.*


%changelog
* Wed Oct 15 2014 umeabot <umeabot> 3.6-10.mga5
+ Revision: 738834
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 3.6-9.mga5
+ Revision: 726078
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 3.6-8.mga5
+ Revision: 678709
- Mageia 5 Mass Rebuild

* Mon Sep 15 2014 tv <tv> 3.6-7.mga5
+ Revision: 675539
- rebuild for new rpm

* Tue Jun 03 2014 pterjan <pterjan> 3.6-6.mga5
+ Revision: 630768
- Rebuild for perl 5.20

* Sat May 31 2014 pterjan <pterjan> 3.6-5.mga5
+ Revision: 629670
- Rebuild for new Python

* Sat May 31 2014 pterjan <pterjan> 3.6-4.mga5
+ Revision: 628154
- Rebuild for new Python

* Mon Oct 21 2013 umeabot <umeabot> 3.6-3.mga4
+ Revision: 540979
- Mageia 4 Mass Rebuild

* Thu Oct 10 2013 philippem <philippem> 3.6-2.mga4
+ Revision: 494702
- add bytecompiled .py files
- do not provide private python extension libs

* Thu Jun 20 2013 tv <tv> 3.6-1.mga4
+ Revision: 445254
- BR python3-devel
- BR python3
- new release
- new python3 submodule

* Wed May 29 2013 tv <tv> 3.5git-7.mga4
+ Revision: 430008
- rebuild for new perl

* Tue Jan 22 2013 fwang <fwang> 3.5git-6.mga3
+ Revision: 390747
- update rpm group

* Fri Jan 11 2013 umeabot <umeabot> 3.5git-5.mga3
+ Revision: 348720
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Dec 18 2012 tv <tv> 3.5git-4.mga3
+ Revision: 332285
- rebuild for new rpm

* Fri Nov 30 2012 tv <tv> 3.5git-3.mga3
+ Revision: 323493
- BR perl-devel
- patch 1: add a perl binding

* Sun Jun 10 2012 tv <tv> 3.5git-2.mga3
+ Revision: 259361
- rebuild for new rpm-4.10.0

* Sat Mar 24 2012 bcornec <bcornec> 3.5git-1.mga2
+ Revision: 226129
- Update Groups to correct values
- Import deltarpm
- rename previsou pkg
- Created package structure for python-deltarpm.

